@@ -17,8 +17,13 @@
  *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "mutt.h"
 #include "mutt_menu.h"
+#include "attach.h"
 #include "mutt_curses.h"
 #include "keymap.h"
 #include "rfc1524.h"
