@@ -17,6 +17,10 @@
  *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "mutt.h"
 #include "mutt_menu.h"
 #include "mutt_curses.h"
@@ -134,16 +138,14 @@ int _mutt_get_field (/* const */ char *field, char *buf, size_t buflen, int comp
   return (ret);
 }
 
-int mutt_get_password (char *msg, char *buf, size_t buflen)
+int mutt_get_field_unbuffered (char *msg, char *buf, size_t buflen, int flags)
 {
   int rc;
-  
-  CLEARLINE (LINES-1);
-  addstr (msg);
+
   set_option (OPTUNBUFFEREDINPUT);
-  rc = mutt_enter_string (buf, buflen, LINES - 1, mutt_strlen (msg), M_PASS);
+  rc = mutt_get_field (msg, buf, buflen, flags);
   unset_option (OPTUNBUFFEREDINPUT);
-  CLEARLINE (LINES-1);
+
   return (rc);
 }
 
