@@ -23,6 +23,7 @@
 #include "mutt.h"
 #include "mutt_curses.h"
 #include "mutt_menu.h"
+#include "attach.h"
 #include "mailbox.h"
 #include "mapping.h"
 #include "sort.h"
@@ -173,7 +174,7 @@ int index_color (int index_no)
 {
   HEADER *h = Context->hdrs[Context->v2r[index_no]];
 
-  if (h->pair)
+  if (h && h->pair)
     return h->pair;
 
   mutt_set_header_color (Context, h);
@@ -563,8 +564,10 @@ int mutt_index_menu (void)
 	menu_status_line (buf, sizeof (buf), menu, NONULL (Status));
 	CLEARLINE (option (OPTSTATUSONTOP) ? 0 : LINES-2);
 	SETCOLOR (MT_COLOR_STATUS);
+        BKGDSET (MT_COLOR_STATUS);
 	mutt_paddstr (COLS, buf);
 	SETCOLOR (MT_COLOR_NORMAL);
+        BKGDSET (MT_COLOR_NORMAL);
 	menu->redraw &= ~REDRAW_STATUS;
       }
 
@@ -576,6 +579,8 @@ int mutt_index_menu (void)
 
       if (option (OPTARROWCURSOR))
 	move (menu->current - menu->top + menu->offset, 2);
+      else if (option (OPTBRAILLEFRIENDLY))
+	move (menu->current - menu->top + menu->offset, 0);
       else
 	move (menu->current - menu->top + menu->offset, COLS - 1);
       mutt_refresh ();
@@ -934,6 +939,11 @@ CHECK_IMAP_ACL(IMAP_ACL_DELETE);
 	else
 	{
 	  mutt_set_flag (Context, CURHDR, M_TAG, !CURHDR->tagged);
+
+	  Context->last_tag = CURHDR->tagged ? CURHDR :
+	    ((Context->last_tag == CURHDR && !CURHDR->tagged)
+	     ? NULL : Context->last_tag);
+
 	  menu->redraw = REDRAW_STATUS;
 	  if (option (OPTRESOLVE) && menu->current < Context->vcount - 1)
 	  {
@@ -1071,6 +1081,7 @@ CHECK_IMAP_ACL(IMAP_ACL_DELETE);
 	  mutt_error (_("%s is not a mailbox."), buf);
 	  break;
 	}
+	mutt_str_replace (&CurrentFolder, buf);
 
         if (Context)
         {
@@ -1173,6 +1184,77 @@ CHECK_IMAP_ACL(IMAP_ACL_DELETE);
 	}
 	break;
 
+      case OP_MAIN_BREAK_THREAD:
+
+	CHECK_MSGCOUNT;
+        CHECK_VISIBLE;
+	CHECK_READONLY;
+
+        if ((Sort & SORT_MASK) != SORT_THREADS)
+	  mutt_error _("Threading is not enabled.");
+	else
+	{
+	  {
+	    HEADER *oldcur = CURHDR;
+
+	    mutt_break_thread (CURHDR);
+	    mutt_sort_headers (Context, 1);
+	    menu->current = oldcur->virtual;
+	  }
+
+	  Context->changed = 1;
+	  mutt_message _("Thread broken");
+
+	  if (menu->menu == MENU_PAGER)
+	  {
+	    op = OP_DISPLAY_MESSAGE;
+	    continue;
+	  }
+	  else
+	    menu->redraw |= REDRAW_INDEX;
+	}
+
+	  break;
+
+      case OP_MAIN_LINK_THREADS:
+
+	CHECK_MSGCOUNT;
+        CHECK_VISIBLE;
+	CHECK_READONLY;
+
+        if ((Sort & SORT_MASK) != SORT_THREADS)
+	  mutt_error _("Threading is not enabled.");
+	else if (!CURHDR->env->message_id)
+	  mutt_error _("No Message-ID: header available to link thread");
+	else if (!tag && (!Context->last_tag || !Context->last_tag->tagged))
+	  mutt_error _("First, please tag a message to be linked here");
+	else 
+	{
+	  HEADER *oldcur = CURHDR;
+
+	  if (mutt_link_threads (CURHDR, tag ? NULL : Context->last_tag,
+				 Context))
+	  {
+	    mutt_sort_headers (Context, 1);
+	    menu->current = oldcur->virtual;
+	    
+	    Context->changed = 1;
+	    mutt_message _("Threads linked");
+	  }
+	  else
+	    mutt_error _("No thread linked");
+	}
+
+	if (menu->menu == MENU_PAGER)
+	{
+	  op = OP_DISPLAY_MESSAGE;
+	  continue;
+	}
+	else
+	  menu->redraw |= REDRAW_STATUS | REDRAW_INDEX;
+
+	break;
+
       case OP_EDIT_TYPE:
 
 	CHECK_MSGCOUNT;
