@@ -20,6 +20,10 @@
 
 #define MAIN_C 1
 
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "mutt.h"
 #include "mutt_curses.h"
 #include "keymap.h"
@@ -55,11 +59,11 @@ Mutt is free software, and you are welcome to redistribute it\n\
 under certain conditions; type `mutt -vv' for details.\n");
 
 static const char *Copyright = N_("\
-Copyright (C) 1996-2002 Michael R. Elkins <me@mutt.org>\n\
+Copyright (C) 1996-2004 Michael R. Elkins <me@mutt.org>\n\
 Copyright (C) 1996-2002 Brandon Long <blong@fiction.net>\n\
-Copyright (C) 1997-2002 Thomas Roessler <roessler@does-not-exist.org>\n\
-Copyright (C) 1998-2002 Werner Koch <wk@isil.d.shuttle.de>\n\
-Copyright (C) 1999-2002 Brendan Cully <brendan@kublai.com>\n\
+Copyright (C) 1997-2005 Thomas Roessler <roessler@does-not-exist.org>\n\
+Copyright (C) 1998-2005 Werner Koch <wk@isil.d.shuttle.de>\n\
+Copyright (C) 1999-2005 Brendan Cully <brendan@kublai.com>\n\
 Copyright (C) 1999-2002 Tommi Komulainen <Tommi.Komulainen@iki.fi>\n\
 Copyright (C) 2000-2002 Edmund Grimley Evans <edmundo@rano.org>\n\
 \n\
@@ -95,6 +99,7 @@ static void mutt_usage (void)
 "usage: mutt [ -nRyzZ ] [ -e <cmd> ] [ -F <file> ] [ -m <type> ] [ -f <file> ]\n\
        mutt [ -nR ] [ -e <cmd> ] [ -F <file> ] -Q <query> [ -Q <query> ] [...]\n\
        mutt [ -nR ] [ -e <cmd> ] [ -F <file> ] -A <alias> [ -A <alias> ] [...]\n\
+       mutt [ -nR ] [ -e <cmd> ] [ -F <file> ] -D\n\
        mutt [ -nx ] [ -e <cmd> ] [ -a <file> ] [ -F <file> ] [ -H <file> ] [ -i <file> ] [ -s <subj> ] [ -b <addr> ] [ -c <addr> ] <addr> [ ... ]\n\
        mutt [ -n ] [ -e <cmd> ] [ -F <file> ] -p\n\
        mutt -v[v]\n\
@@ -104,11 +109,16 @@ options:\n\
   -a <file>\tattach a file to the message\n\
   -b <address>\tspecify a blind carbon-copy (BCC) address\n\
   -c <address>\tspecify a carbon-copy (CC) address\n\
-  -e <command>\tspecify a command to be executed after initialization\n\
+  -D\t\tprint the value of all variables to stderr");
+#if DEBUG
+  puts _("  -d <level>\tlog debugging output to ~/.muttdebug0");
+#endif
+  puts _(
+"  -e <command>\tspecify a command to be executed after initialization\n\
   -f <file>\tspecify which mailbox to read\n\
   -F <file>\tspecify an alternate muttrc file\n\
-  -H <file>\tspecify a draft file to read header from\n\
-  -i <file>\tspecify a file which Mutt should include in the reply\n\
+  -H <file>\tspecify a draft file to read header and body from\n\
+  -i <file>\tspecify a file which Mutt should include in the body\n\
   -m <type>\tspecify a default mailbox type\n\
   -n\t\tcauses Mutt not to read the system Muttrc\n\
   -p\t\trecall a postponed message\n\
@@ -513,6 +523,7 @@ int main (int argc, char **argv)
   int version = 0;
   int i;
   int explicit_folder = 0;
+  int dump_variables = 0;
   extern char *optarg;
   extern int optind;
 
@@ -542,7 +553,7 @@ int main (int argc, char **argv)
   memset (Options, 0, sizeof (Options));
   memset (QuadOptions, 0, sizeof (QuadOptions));
   
-  while ((i = getopt (argc, argv, "A:a:b:F:f:c:d:e:H:s:i:hm:npQ:RvxyzZ")) != EOF)
+  while ((i = getopt (argc, argv, "A:a:b:F:f:c:Dd:e:H:s:i:hm:npQ:RvxyzZ")) != EOF)
     switch (i)
     {
       case 'A':
@@ -573,6 +584,10 @@ int main (int argc, char **argv)
 	  msg->env->cc = rfc822_parse_adrlist (msg->env->cc, optarg);
 	break;
 
+      case 'D':
+	dump_variables = 1;
+	break;
+
       case 'd':
 #ifdef DEBUG
 	debuglevel = atoi (optarg);
@@ -658,7 +673,7 @@ int main (int argc, char **argv)
   }
 
   /* Check for a batch send. */
-  if (!isatty (0) || queries || alias_queries)
+  if (!isatty (0) || queries || alias_queries || dump_variables)
   {
     set_option (OPTNOCURSES);
     sendflags = SENDBATCH;
@@ -678,6 +693,8 @@ int main (int argc, char **argv)
 
   if (queries)
     return mutt_query_variables (queries);
+  if (dump_variables)
+    return mutt_dump_variables();
 
   if (alias_queries)
   {
@@ -906,6 +923,7 @@ int main (int argc, char **argv)
       strfcpy (folder, NONULL(Spoolfile), sizeof (folder));
     mutt_expand_path (folder, sizeof (folder));
 
+    mutt_str_replace (&CurrentFolder, folder);
     mutt_str_replace (&LastFolder, folder);
 
     if (flags & M_IGNORE)
