@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-3 Brendan Cully <brendan@kublai.com>
+ * Copyright (C) 2000-5 Brendan Cully <brendan@kublai.com>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -243,8 +243,7 @@ dprint(1,(debugfile, "local ip: %s, remote ip:%s\n", iplocalport, ipremoteport))
 
   /*** set sasl IP properties, necessary for use with krb4 ***/
   /* Do we need to fail if this fails? I would assume having these unset
-   * would just disable KRB4. Who wrote this code? I'm not sure how this
-   * interacts with the NSS code either, since that mucks with the fd. */
+   * would just disable KRB4. Who wrote this code? */
 #ifndef USE_SASL2 /* with SASLv2 this all happens in sasl_client_new */
   {
     struct sockaddr_in local, remote;
@@ -294,10 +293,6 @@ dprint(1,(debugfile, "local ip: %s, remote ip:%s\n", iplocalport, ipremoteport))
     return -1;
   }
 
-  /* we currently don't have an SSF finder for NSS (I don't know the API).
-   * If someone does it'd probably be trivial to write mutt_nss_get_ssf().
-   * I have a feeling more SSL code could be shared between those two files,
-   * but I haven't looked into it yet, since I still don't know the APIs. */
 #if defined(USE_SSL) || defined(USE_GNUTLS)
   if (conn->ssf)
   {
@@ -334,12 +329,12 @@ sasl_callback_t* mutt_sasl_get_callbacks (ACCOUNT* account)
 
   callback = mutt_sasl_callbacks;
 
-  callback->id = SASL_CB_AUTHNAME;
+  callback->id = SASL_CB_USER;
   callback->proc = mutt_sasl_cb_authname;
   callback->context = account;
   callback++;
 
-  callback->id = SASL_CB_USER;
+  callback->id = SASL_CB_AUTHNAME;
   callback->proc = mutt_sasl_cb_authname;
   callback->context = account;
   callback++;
@@ -377,7 +372,7 @@ int mutt_sasl_interact (sasl_interact_t* interaction)
 
     interaction->len = mutt_strlen (resp)+1;
     interaction->result = safe_malloc (interaction->len);
-    memcpy (interaction->result, resp, interaction->len);
+    memcpy ((char *)interaction->result, resp, interaction->len);
 
     interaction++;
   }
@@ -429,17 +424,17 @@ void mutt_sasl_setup_conn (CONNECTION* conn, sasl_conn_t* saslconn)
 
   /* preserve old functions */
   sasldata->sockdata = conn->sockdata;
-  sasldata->open = conn->open;
-  sasldata->close = conn->close;
-  sasldata->read = conn->read;
-  sasldata->write = conn->write;
+  sasldata->msasl_open = conn->conn_open;
+  sasldata->msasl_close = conn->conn_close;
+  sasldata->msasl_read = conn->conn_read;
+  sasldata->msasl_write = conn->conn_write;
 
   /* and set up new functions */
   conn->sockdata = sasldata;
-  conn->open = mutt_sasl_conn_open;
-  conn->close = mutt_sasl_conn_close;
-  conn->read = mutt_sasl_conn_read;
-  conn->write = mutt_sasl_conn_write;
+  conn->conn_open = mutt_sasl_conn_open;
+  conn->conn_close = mutt_sasl_conn_close;
+  conn->conn_read = mutt_sasl_conn_read;
+  conn->conn_write = mutt_sasl_conn_write;
 }
 
 /* mutt_sasl_cb_log: callback to log SASL messages */
@@ -450,8 +445,7 @@ static int mutt_sasl_cb_log (void* context, int priority, const char* message)
   return SASL_OK;
 }
 
-/* mutt_sasl_cb_authname: callback to retrieve authname or user (mutt
- *   doesn't distinguish, even if some SASL plugins do) from ACCOUNT */
+/* mutt_sasl_cb_authname: callback to retrieve authname or user from ACCOUNT */
 static int mutt_sasl_cb_authname (void* context, int id, const char** result,
   unsigned* len)
 {
@@ -468,11 +462,19 @@ static int mutt_sasl_cb_authname (void* context, int id, const char** result,
 	      id == SASL_CB_AUTHNAME ? "authname" : "user",
 	      account->host, account->port));
 
-  if (mutt_account_getuser (account))
-    return SASL_FAIL;
-
-  *result = account->user;
-
+  if (id == SASL_CB_AUTHNAME)
+  {
+    if (mutt_account_getlogin (account))
+      return SASL_FAIL;
+    *result = account->login;
+  }
+  else
+  {
+    if (mutt_account_getuser (account))
+      return SASL_FAIL;
+    *result = account->user;
+  }
+  
   if (len)
     *len = strlen (*result);
 
@@ -489,7 +491,7 @@ static int mutt_sasl_cb_pass (sasl_conn_t* conn, void* context, int id,
     return SASL_BADPARAM;
 
   dprint (2, (debugfile,
-    "mutt_sasl_cb_pass: getting password for %s@%s:%u\n", account->user,
+    "mutt_sasl_cb_pass: getting password for %s@%s:%u\n", account->login,
     account->host, account->port));
 
   if (mutt_account_getpass (account))
@@ -499,7 +501,7 @@ static int mutt_sasl_cb_pass (sasl_conn_t* conn, void* context, int id,
 
   *psecret = (sasl_secret_t*) safe_malloc (sizeof (sasl_secret_t) + len);
   (*psecret)->len = len;
-  strcpy ((*psecret)->data, account->pass);	/* __STRCPY_CHECKED__ */
+  strcpy ((char*)(*psecret)->data, account->pass);	/* __STRCPY_CHECKED__ */
 
   return SASL_OK;
 }
@@ -515,7 +517,7 @@ static int mutt_sasl_conn_open (CONNECTION* conn)
 
   sasldata = (SASL_DATA*) conn->sockdata;
   conn->sockdata = sasldata->sockdata;
-  rc = (sasldata->open) (conn);
+  rc = (sasldata->msasl_open) (conn);
   conn->sockdata = sasldata;
 
   return rc;
@@ -532,10 +534,10 @@ static int mutt_sasl_conn_close (CONNECTION* conn)
 
   /* restore connection's underlying methods */
   conn->sockdata = sasldata->sockdata;
-  conn->open = sasldata->open;
-  conn->close = sasldata->close;
-  conn->read = sasldata->read;
-  conn->write = sasldata->write;
+  conn->conn_open = sasldata->msasl_open;
+  conn->conn_close = sasldata->msasl_close;
+  conn->conn_read = sasldata->msasl_read;
+  conn->conn_write = sasldata->msasl_write;
 
   /* release sasl resources */
   sasl_dispose (&sasldata->saslconn);
@@ -545,7 +547,7 @@ static int mutt_sasl_conn_close (CONNECTION* conn)
   FREE (&sasldata);
 
   /* call underlying close */
-  rc = (conn->close) (conn);
+  rc = (conn->conn_close) (conn);
 
   return rc;
 }
@@ -585,7 +587,7 @@ static int mutt_sasl_conn_read (CONNECTION* conn, char* buf, size_t len)
     do
     {
       /* call the underlying read function to fill the buffer */
-      rc = (sasldata->read) (conn, buf, len);
+      rc = (sasldata->msasl_read) (conn, buf, len);
       if (rc <= 0)
 	goto out;
 
@@ -609,7 +611,7 @@ static int mutt_sasl_conn_read (CONNECTION* conn, char* buf, size_t len)
     rc = olen;
   }
   else
-    rc = (sasldata->read) (conn, buf, len);
+    rc = (sasldata->msasl_read) (conn, buf, len);
 
   out:
     conn->sockdata = sasldata;
@@ -649,7 +651,7 @@ static int mutt_sasl_conn_write (CONNECTION* conn, const char* buf,
 	goto fail;
       }
 
-      rc = (sasldata->write) (conn, pbuf, plen);
+      rc = (sasldata->msasl_write) (conn, pbuf, plen);
 #ifndef USE_SASL2
       FREE (&pbuf);
 #endif
@@ -663,7 +665,7 @@ static int mutt_sasl_conn_write (CONNECTION* conn, const char* buf,
   }
   else
   /* just write using the underlying socket function */
-    rc = (sasldata->write) (conn, buf, len);
+    rc = (sasldata->msasl_write) (conn, buf, len);
   
   conn->sockdata = sasldata;
 
