@@ -21,11 +21,14 @@
 
 #include "mutt_socket.h"
 
-extern char *SslCertFile;
-extern char *SslEntropyFile;
-
+#ifdef USE_SSL
 int mutt_ssl_starttls (CONNECTION* conn);
 
 extern int ssl_socket_setup (CONNECTION *conn);
+#endif
+#ifdef USE_GNUTLS
+int mutt_gnutls_starttls (CONNECTION* conn);
 
+extern int mutt_gnutls_socket_setup (CONNECTION *conn);
+#endif
 #endif /* _MUTT_SSL_H_ */
