@@ -77,10 +77,10 @@ int mutt_gnutls_socket_setup (CONNECTION* conn)
   if (tls_init() < 0)
     return -1;
 
-  conn->open	= tls_socket_open;
-  conn->read	= tls_socket_read;
-  conn->write	= tls_socket_write;
-  conn->close	= tls_socket_close;
+  conn->conn_open	= tls_socket_open;
+  conn->conn_read	= tls_socket_read;
+  conn->conn_write	= tls_socket_write;
+  conn->conn_close	= tls_socket_close;
 
   return 0;
 }
@@ -92,7 +92,7 @@ static int tls_socket_read (CONNECTION* conn, char* buf, size_t len)
 
   if (!data)
   {
-    mutt_error ("Error: no TLS socket open");
+    mutt_error (_("Error: no TLS socket open"));
     mutt_sleep (2);
     return -1;
   }
@@ -114,7 +114,7 @@ static int tls_socket_write (CONNECTION* conn, const char* buf, size_t len)
 
   if (!data)
   {
-    mutt_error ("Error: no TLS socket open");
+    mutt_error (_("Error: no TLS socket open"));
     mutt_sleep (2);
     return -1;
   }
@@ -151,9 +151,9 @@ int mutt_gnutls_starttls (CONNECTION* conn)
   if (tls_negotiate (conn) < 0)
     return -1;
 
-  conn->read	= tls_socket_read;
-  conn->write	= tls_socket_write;
-  conn->close	= tls_starttls_close;
+  conn->conn_read	= tls_socket_read;
+  conn->conn_write	= tls_socket_write;
+  conn->conn_close	= tls_starttls_close;
 
   return 0;
 }
@@ -298,9 +298,9 @@ static int tls_starttls_close (CONNECTION* conn)
   int rc;
 
   rc = tls_socket_close (conn);
-  conn->read = raw_socket_read;
-  conn->write = raw_socket_write;
-  conn->close = raw_socket_close;
+  conn->conn_read = raw_socket_read;
+  conn->conn_write = raw_socket_write;
+  conn->conn_close = raw_socket_close;
 
   return rc;
 }
@@ -342,8 +342,8 @@ static int tls_compare_certificates (const gnutls_datum *peercert)
       return 0;
     }
 
-    ptr = (unsigned char *)strstr(b64_data.data, CERT_SEP) + 1;
-    ptr = (unsigned char *)strstr(ptr, CERT_SEP);
+    ptr = (unsigned char *)strstr((char*)b64_data.data, CERT_SEP) + 1;
+    ptr = (unsigned char *)strstr((char*)ptr, CERT_SEP);
 
     b64_data.size = b64_data.size - (ptr - b64_data.data);
     b64_data.data = ptr;
@@ -474,10 +474,9 @@ static int tls_check_certificate (CONNECTION* conn)
   MUTTMENU *menu;
   int done, row, i, ret;
   FILE *fp;
-  gnutls_x509_dn dn;
   time_t t;
   const gnutls_datum *cert_list;
-  int cert_list_size = 0;
+  unsigned int cert_list_size = 0;
   gnutls_certificate_status certstat;
   char datestr[30];
   gnutls_x509_crt cert;
@@ -514,7 +513,7 @@ static int tls_check_certificate (CONNECTION* conn)
   /* We only support X.509 certificates (not OpenPGP) at the moment */
   if (gnutls_certificate_type_get(state) != GNUTLS_CRT_X509)
   {
-    mutt_error (_("Error certificate is not X.509"));
+    mutt_error (_("Certificate is not X.509"));
     mutt_sleep (2);
     return 0;
   }
