@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000 Manoj Kasichainula <manoj@io.com>
- * Copyright (C) 2001 Brendan Cully <brendan@kublai.com>
+ * Copyright (C) 2001,2005 Brendan Cully <brendan@kublai.com>
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -49,10 +49,10 @@ static int tunnel_socket_write (CONNECTION* conn, const char* buf, size_t len);
 /* -- public functions -- */
 int mutt_tunnel_socket_setup (CONNECTION *conn)
 {
-  conn->open = tunnel_socket_open;
-  conn->close = tunnel_socket_close;
-  conn->read = tunnel_socket_read;
-  conn->write = tunnel_socket_write;
+  conn->conn_open = tunnel_socket_open;
+  conn->conn_close = tunnel_socket_close;
+  conn->conn_read = tunnel_socket_read;
+  conn->conn_write = tunnel_socket_write;
 
   return 0;
 }
@@ -127,10 +127,18 @@ static int tunnel_socket_open (CONNECTION *conn)
 static int tunnel_socket_close (CONNECTION* conn)
 {
   TUNNEL_DATA* tunnel = (TUNNEL_DATA*) conn->sockdata;
+  int status;
 
   close (tunnel->readfd);
   close (tunnel->writefd);
-  waitpid (tunnel->pid, NULL, 0);
+  waitpid (tunnel->pid, &status, 0);
+  if (!WIFEXITED(status) || WEXITSTATUS(status))
+  {
+    mutt_error(_("Tunnel to %s returned error %d (%s)"), conn->account.host,
+               WEXITSTATUS(status),
+               NONULL(mutt_strsysexit(WEXITSTATUS(status))));
+    mutt_sleep (2);
+  }
   FREE (&conn->sockdata);
 
   return 0;
