@@ -1165,6 +1165,8 @@ int mx_sync_mailbox (CONTEXT *ctx, int *index_hint)
         ctx->deleted = 0;
       }
     }
+    else if (ctx->last_tag && ctx->last_tag->deleted)
+      ctx->last_tag = NULL; /* reset last tagged msg now useless */
   }
 
   /* really only for IMAP - imap_sync_mailbox results in a call to
@@ -1238,7 +1240,10 @@ int imap_open_new_message (MESSAGE *msg, CONTEXT *dest, HEADER *hdr)
 
   mutt_mktemp(tmp);
   if ((msg->fp = safe_fopen (tmp, "w")) == NULL)
+  {
+    mutt_perror (tmp);
     return (-1);
+  }
   msg->path = safe_strdup(tmp);
   return 0;
 }
