@@ -62,7 +62,7 @@
 #include "mutt_menu.h"
 
 
-char PgpPass[STRING];
+char PgpPass[LONG_STRING];
 time_t PgpExptime = 0; /* when does the cached passphrase expire? */
 
 void pgp_void_passphrase (void)
@@ -233,17 +233,18 @@ static void pgp_copy_clearsigned (FILE *fpin, STATE *s, char *charset)
 
 /* Support for the Application/PGP Content Type. */
 
-void pgp_application_pgp_handler (BODY *m, STATE *s)
+int pgp_application_pgp_handler (BODY *m, STATE *s)
 {
   int needpass = -1, pgp_keyblock = 0;
   int clearsign = 0, rv, rc;
+  int c;
   long start_pos = 0;
   long bytes, last_pos, offset;
   char buf[HUGE_STRING];
   char outfile[_POSIX_PATH_MAX];
   char tmpfname[_POSIX_PATH_MAX];
   FILE *pgpout = NULL, *pgpin = NULL, *pgperr = NULL;
-  FILE *tmpfp;
+  FILE *tmpfp = NULL;
   pid_t thepid;
 
   short maybe_goodsig = 1;
@@ -300,7 +301,7 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
       if ((tmpfp = safe_fopen (tmpfname, "w+")) == NULL)
       {
 	mutt_perror (tmpfname);
-	return;
+	return -1;
       }
       
       fputs (buf, tmpfp);
@@ -330,7 +331,7 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
 	if ((pgpout = safe_fopen (outfile, "w+")) == NULL)
 	{
 	  mutt_perror (tmpfname);
-	  return;
+	  return -1;
 	}
 	
 	if ((thepid = pgp_invoke_decode (&pgpin, NULL, &pgperr, -1,
@@ -367,21 +368,31 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
 	  if (s->flags & M_DISPLAY)
 	  {
 	    if (rc == 0) have_any_sigs = 1;
-/*
- * Sig is bad if
- * gpg_good_sign-pattern did not match || pgp_decode_command returned not 0
- * Sig _is_ correct if
- *  gpg_good_sign="" && pgp_decode_command returned 0
- */
+	    /*
+	     * Sig is bad if
+	     * gpg_good_sign-pattern did not match || pgp_decode_command returned not 0
+	     * Sig _is_ correct if
+	     *  gpg_good_sign="" && pgp_decode_command returned 0
+	     */
 	    if (rc == -1 || rv) maybe_goodsig = 0;
-
-	    state_putc ('\n', s);
+	    
 	    state_attach_puts (_("[-- End of PGP output --]\n\n"), s);
 	  }
 	}
+	
+        /* treat empty result as sign of failure */
+	rewind (pgpout);
+        if ((c = fgetc (pgpout)) == EOF)
+	{
+          mutt_error _("Could not decrypt PGP message");
+          pgp_void_passphrase ();
+          rc = -1;
+          
+          goto out;
+        }
+	ungetc (c, pgpout);
       }
       
-
       /*
        * Now, copy cleartext to the screen.  NOTE - we expect that PGP
        * outputs utf-8 cleartext.  This may not always be true, but it 
@@ -420,23 +431,15 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
       {
 	state_putc ('\n', s);
 	if (needpass)
+        {
 	  state_attach_puts (_("[-- END PGP MESSAGE --]\n"), s);
+          mutt_message _("PGP message successfully decrypted.");
+        }
 	else if (pgp_keyblock)
 	  state_attach_puts (_("[-- END PGP PUBLIC KEY BLOCK --]\n"), s);
 	else
 	  state_attach_puts (_("[-- END PGP SIGNED MESSAGE --]\n"), s);
       }
-
-      if (tmpfp)
-      {
-	safe_fclose (&tmpfp);
-	mutt_unlink (tmpfname);
-      }
-      if (pgpout)
-      {
-	safe_fclose (&pgpout);
-	mutt_unlink (outfile);
-      }
     }
     else
     {
@@ -447,13 +450,29 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
     }
   }
 
+  rc = 0;
+
+out:
   m->goodsig = (maybe_goodsig && have_any_sigs);
 
+  if (tmpfp)
+  {
+    safe_fclose (&tmpfp);
+    mutt_unlink (tmpfname);
+  }
+  if (pgpout)
+  {
+    safe_fclose (&pgpout);
+    mutt_unlink (outfile);
+  }
+  
   if (needpass == -1)
   {
     state_attach_puts (_("[-- Error: could not find beginning of PGP message! --]\n\n"), s);
-    return;
+    return -1;
   }
+  
+  return rc;
 }
 
 static int pgp_check_traditional_one_body (FILE *fp, BODY *b, int tagged_only)
@@ -730,6 +749,7 @@ BODY *pgp_decrypt_part (BODY *a, STATE *s, FILE *fpout, BODY *p)
   char pgperrfile[_POSIX_PATH_MAX];
   char pgptmpfile[_POSIX_PATH_MAX];
   pid_t thepid;
+  int rv;
   
   mutt_mktemp (pgperrfile);
   if ((pgperr = safe_fopen (pgperrfile, "w+")) == NULL)
@@ -785,15 +805,17 @@ BODY *pgp_decrypt_part (BODY *a, STATE *s, FILE *fpout, BODY *p)
   }
 
   fclose (pgpout);
-  mutt_wait_filter (thepid);
+  rv = mutt_wait_filter (thepid);
   mutt_unlink(pgptmpfile);
   
   if (s->flags & M_DISPLAY)
   {
     fflush (pgperr);
     rewind (pgperr);
-    if (pgp_copy_checksig (pgperr, s->fpout) == 0 && p)
+    if (pgp_copy_checksig (pgperr, s->fpout) == 0 && !rv && p)
       p->goodsig = 1;
+    else
+      p->goodsig = 0;
     state_attach_puts (_("[-- End of PGP output --]\n\n"), s);
   }
   fclose (pgperr);
@@ -802,7 +824,11 @@ BODY *pgp_decrypt_part (BODY *a, STATE *s, FILE *fpout, BODY *p)
   rewind (fpout);
   
   if (fgetc (fpout) == EOF)
+  {
+    mutt_error _("Decryption failed");
+    pgp_void_passphrase ();
     return NULL;
+  }
 
   rewind (fpout);
   
@@ -856,12 +882,13 @@ int pgp_decrypt_mime (FILE *fpin, FILE **fpout, BODY *b, BODY **cur)
   return (0);
 }
 
-void pgp_encrypted_handler (BODY *a, STATE *s)
+int pgp_encrypted_handler (BODY *a, STATE *s)
 {
   char tempfile[_POSIX_PATH_MAX];
   FILE *fpout, *fpin;
   BODY *tattach;
   BODY *p = a;
+  int rc = 0;
   
   a = a->parts;
   if (!a || a->type != TYPEAPPLICATION || !a->subtype || 
@@ -871,7 +898,7 @@ void pgp_encrypted_handler (BODY *a, STATE *s)
   {
     if (s->flags & M_DISPLAY)
       state_attach_puts (_("[-- Error: malformed PGP/MIME message! --]\n\n"), s);
-    return;
+    return -1;
   }
 
   /*
@@ -884,7 +911,7 @@ void pgp_encrypted_handler (BODY *a, STATE *s)
   {
     if (s->flags & M_DISPLAY)
       state_attach_puts (_("[-- Error: could not create temporary file! --]\n"), s);
-    return;
+    return -1;
   }
 
   if (s->flags & M_DISPLAY) crypt_current_time (s, "PGP");
@@ -896,7 +923,7 @@ void pgp_encrypted_handler (BODY *a, STATE *s)
 
     fpin = s->fpin;
     s->fpin = fpout;
-    mutt_body_handler (tattach, s);
+    rc = mutt_body_handler (tattach, s);
     s->fpin = fpin;
 
     /* 
@@ -916,10 +943,21 @@ void pgp_encrypted_handler (BODY *a, STATE *s)
     }
 
     mutt_free_body (&tattach);
+    /* clear 'Invoking...' message, since there's no error */
+    mutt_message _("PGP message successfully decrypted.");
+  }
+  else
+  {
+    mutt_error _("Could not decrypt PGP message");
+    /* void the passphrase, even if it's not necessarily the problem */
+    pgp_void_passphrase ();
+    rc = -1;
   }
 
   fclose (fpout);
   mutt_unlink(tempfile);
+
+  return rc;
 }
 
 /* ----------------------------------------------------------------------------
@@ -1016,6 +1054,8 @@ BODY *pgp_sign_message (BODY *a)
   if (empty)
   {
     unlink (sigfile);
+    /* most likely error is a bad passphrase, so automatically forget it */
+    pgp_void_passphrase ();
     return (NULL); /* fatal error while signing */
   }
 
@@ -1264,6 +1304,8 @@ BODY *pgp_encrypt_message (BODY *a, char *keylist, int sign)
   if (empty)
   {
     /* fatal error while trying to encrypt message */
+    if (sign)
+      pgp_void_passphrase (); /* just in case */
     unlink (tempfile);
     return (NULL);
   }
@@ -1438,6 +1480,8 @@ BODY *pgp_traditional_encryptsign (BODY *a, int flags, char *keylist)
   
   if (empty)
   {
+    if (flags & SIGN)
+      pgp_void_passphrase (); /* just in case */
     unlink (pgpoutfile);
     return NULL;
   }
@@ -1486,6 +1530,11 @@ int pgp_send_menu (HEADER *msg, int *redraw)
   
   if (!(WithCrypto & APPLICATION_PGP))
     return msg->security;
+
+  /* If autoinline and no crypto options set, then set inline. */
+  if (option (OPTPGPAUTOINLINE) && 
+      !((msg->security & APPLICATION_PGP) && (msg->security & (SIGN|ENCRYPT))))
+    msg->security |= INLINE;
   
   snprintf (prompt, sizeof (prompt), 
 	    _("PGP (e)ncrypt, (s)ign, sign (a)s, (b)oth, %s, or (c)lear? "),
