@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
  *
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -20,5 +20,5 @@
  */
 
 void rfc2231_decode_parameters (PARAMETER **);
-int rfc2231_encode (char *, size_t, unsigned char *);
+int rfc2231_encode_string (char **);
 
